@@ -216,8 +216,7 @@ impl<'a> IterInfo<'a> {
             .properties
             .by_minute
             .iter()
-            .map(|minute| self.min_timeset(hour, *minute, second, millisecond))
-            .flatten()
+            .flat_map(|minute| self.min_timeset(hour, *minute, second, millisecond))
             .collect::<Vec<Time>>();
         set.sort_by_key(|a| a.time());
         set
