@@ -4,12 +4,12 @@
 
 // Every mask is 7 days longer to handle cross-year weekly periods.
 
-pub(crate) type WdayMask = [usize; 7 * 55];
-pub(crate) type Mask365 = [usize; 365 + 7];
-pub(crate) type Mask366 = [usize; 366 + 7];
-pub(crate) type Mask365Signed = [isize; 365 + 7];
-pub(crate) type Mask366Signed = [isize; 366 + 7];
-pub(crate) type MonthRangeMask = [usize; 13];
+pub(crate) type WdayMask = [u8; 7 * 55];
+pub(crate) type Mask365 = [u8; 365 + 7];
+pub(crate) type Mask366 = [u8; 366 + 7];
+pub(crate) type Mask365Signed = [i8; 365 + 7];
+pub(crate) type Mask366Signed = [i8; 366 + 7];
+pub(crate) type MonthRangeMask = [u16; 13];
 
 const M365: Mask365 = [
     // 31
@@ -253,28 +253,28 @@ const WDAY: WdayMask = [
 ];
 
 #[derive(Clone)]
-pub struct Masks {
-    pub wday: WdayMask,
-    pub m365: Mask365,
-    pub m365range: MonthRangeMask,
-    pub m366: Mask366,
-    pub m366range: MonthRangeMask,
-    pub mday365: Mask365Signed,
-    pub mday366: Mask366Signed,
-    pub nmday365: Mask365Signed,
-    pub nmday366: Mask366Signed,
+pub(crate) struct Masks {
+    pub weekday: WdayMask,
+    pub month_365: Mask365,
+    pub month_365_range: MonthRangeMask,
+    pub month_366: Mask366,
+    pub month_366_range: MonthRangeMask,
+    pub month_day_365: Mask365Signed,
+    pub month_day_366: Mask366Signed,
+    pub neg_month_day_365: Mask365Signed,
+    pub neg_month_day_366: Mask366Signed,
 }
 
-pub const MASKS: Masks = Masks {
-    wday: WDAY,
-    m365: M365,
-    m365range: M365_RANGE,
-    m366: M366,
-    m366range: M366_RANGE,
-    mday365: MDAY365,
-    mday366: MDAY366,
-    nmday365: NMDAY365,
-    nmday366: NMDAY366,
+pub(crate) const MASKS: Masks = Masks {
+    weekday: WDAY,
+    month_365: M365,
+    month_365_range: M365_RANGE,
+    month_366: M366,
+    month_366_range: M366_RANGE,
+    month_day_365: MDAY365,
+    month_day_366: MDAY366,
+    neg_month_day_365: NMDAY365,
+    neg_month_day_366: NMDAY366,
 };
 
 // impl Default for Masks {
