@@ -1,5 +1,7 @@
+mod error;
 mod rrulestr;
 
+pub(crate) use error::ParseError;
 pub(crate) use rrulestr::{
     build_rruleset, finalize_parsed_properties, parse_rrule_string_to_properties,
 };
