@@ -4,8 +4,11 @@
 use crate::{RRuleError, RRuleProperties};
 
 mod check_limits;
+mod error;
 mod validate_properties;
 
+pub(crate) use error::ValidationError;
+
 #[allow(unused_imports)]
 pub(crate) use check_limits::{
     FREQ_DAILY_INTERVAL_MAX, FREQ_HOURLY_INTERVAL_MAX, FREQ_MINUTELY_INTERVAL_MAX,
